# this code is used to test C++ feature

test <- function(){
  
  tmp <- .C("test_c", PACKAGE = "ARTP2")
  
}
